Documentation
¶
Overview ¶
Package websupport implements a DNS provider for WebSupport (websupport.sk), using their REST API v2 (https://rest.websupport.sk/v2/docs).
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AuditRecords ¶
func AuditRecords(records []*models.RecordConfig) []error
AuditRecords returns a list of errors corresponding to the records that aren't supported by this provider. If all records are supported, an empty list is returned.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.